==> ejc-purchasingmanagement-impl-3.0.0-20220613.033944-112-sources.jar: com/ejianc/business/purchasingmanagement/bean/TransportationSummaryEntity.java <==
package com.ejianc.business.purchasingmanagement.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 运费验收明细汇总
 * 
 * @author generator
 * 
 */
 @TableName("ejc_purchasingmanagement_transportationSummary")
public class TransportationSummaryEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="transportationacceptance_id")
    private Long transportationacceptanceId; // 运费验收主键
    @TableField(value="price")
    private BigDecimal price; // 单价
    @TableField(value="quantity")
    private BigDecimal quantity; // 数量
    @TableField(value="amount")
    private BigDecimal amount; // 金额
    @TableField(value="material_tax")
    private BigDecimal materialTax; // 材料税
    @TableField(value="freight_tax")
    private BigDecimal freightTax; // 运费税额
    @TableField(value="freight_rate")
    private BigDecimal freightRate; // 运费税率
    @TableField(value="number_plate")
    private String numberPlate; // 
    @TableField(value="received_date")
    private Date receivedDate; // 
    @TableField(value="total")
    private BigDecimal total; // 
    @TableField(value="purchasereceipt_id")
    private Long purchasereceiptId; // 收货单ID
    @TableField(value="material_id")
    private Long materialId; // 原材料品种主键
    @TableField(value="material_name")
    private String materialName; // 原材料品种名称
    
    
    

    public Long getTransportationacceptanceId() {
        return transportationacceptanceId;
    }

    public void setTransportationacceptanceId(Long transportationacceptanceId) {
        this.transportationacceptanceId = transportationacceptanceId;
    }
    public BigDecimal getPrice() {
        return price;
    }

    public void setPrice(BigDecimal price) {
        this.price = price;
    }
    public BigDecimal getQuantity() {
        return quantity;
    }

    public void setQuantity(BigDecimal quantity) {
        this.quantity = quantity;
    }
    public BigDecimal getAmount() {
        return amount;
    }

    public void setAmount(BigDecimal amount) {
        this.amount = amount;
    }
    public BigDecimal getMaterialTax() {
        return materialTax;
    }

    public void setMaterialTax(BigDecimal materialTax) {
        this.materialTax = materialTax;
    }
    public BigDecimal getFreightTax() {
        return freightTax;
    }

    public void setFreightTax(BigDecimal freightTax) {
        this.freightTax = freightTax;
    }
    public BigDecimal getFreightRate() {
        return freightRate;
    }

    public void setFreightRate(BigDecimal freightRate) {
        this.freightRate = freightRate;
    }
    public String getNumberPlate() {
        return numberPlate;
    }

    public void setNumberPlate(String numberPlate) {
        this.numberPlate = numberPlate;
    }
    public Date getReceivedDate() {
        return receivedDate;
    }

    public void setReceivedDate(Date receivedDate) {
        this.receivedDate = receivedDate;
    }
    public BigDecimal getTotal() {
        return total;
    }

    public void setTotal(BigDecimal total) {
        this.total = total;
    }
    public Long getPurchasereceiptId() {
        return purchasereceiptId;
    }

    public void setPurchasereceiptId(Long purchasereceiptId) {
        this.purchasereceiptId = purchasereceiptId;
    }
    public Long getMaterialId() {
        return materialId;
    }

    public void setMaterialId(Long materialId) {
        this.materialId = materialId;
    }
    public String getMaterialName() {
        return materialName;
    }

    public void setMaterialName(String materialName) {
        this.materialName = materialName;
    }
    
}

==> ejc-purchasingmanagement-impl-3.0.0-20220712.050457-150-sources.jar: com/ejianc/business/purchasingmanagement/bean/TransportationSummaryEntity.java <==
package com.ejianc.business.purchasingmanagement.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 运费验收明细汇总
 * 
 * @author generator
 * 
 */
 @TableName("ejc_purchasingmanagement_transportationSummary")
public class TransportationSummaryEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="transportationacceptance_id")
    private Long transportationacceptanceId; // 运费验收主键
    @TableField(value="price")
    private BigDecimal price; // 单价
    @TableField(value="quantity")
    private BigDecimal quantity; // 数量(收货卸车净重)
    @TableField(value="amount")
    private BigDecimal amount; // 不含税金额
    @TableField(value="material_tax")
    private BigDecimal materialTax; // 材料税
    @TableField(value="freight_tax")
    private BigDecimal freightTax; // 运费税额
    @TableField(value="freight_rate")
    private BigDecimal freightRate; // 运费税率
    @TableField(value="number_plate")
    private String numberPlate; // 车牌号
    @TableField(value="received_date")
    private Date receivedDate; // 收货时间
    @TableField(value="total")
    private BigDecimal total; // 含税金额
    @TableField(value="purchasereceipt_id")
    private Long purchasereceiptId; // 收货单ID
    @TableField(value="material_id")
    private Long materialId; // 合同子表主键
    @TableField(value="material_name")
    private String materialName; //合同子表原材料名称
    
    
    

    public Long getTransportationacceptanceId() {
        return transportationacceptanceId;
    }

    public void setTransportationacceptanceId(Long transportationacceptanceId) {
        this.transportationacceptanceId = transportationacceptanceId;
    }
    public BigDecimal getPrice() {
        return price;
    }

    public void setPrice(BigDecimal price) {
        this.price = price;
    }
    public BigDecimal getQuantity() {
        return quantity;
    }

    public void setQuantity(BigDecimal quantity) {
        this.quantity = quantity;
    }
    public BigDecimal getAmount() {
        return amount;
    }

    public void setAmount(BigDecimal amount) {
        this.amount = amount;
    }
    public BigDecimal getMaterialTax() {
        return materialTax;
    }

    public void setMaterialTax(BigDecimal materialTax) {
        this.materialTax = materialTax;
    }
    public BigDecimal getFreightTax() {
        return freightTax;
    }

    public void setFreightTax(BigDecimal freightTax) {
        this.freightTax = freightTax;
    }
    public BigDecimal getFreightRate() {
        return freightRate;
    }

    public void setFreightRate(BigDecimal freightRate) {
        this.freightRate = freightRate;
    }
    public String getNumberPlate() {
        return numberPlate;
    }

    public void setNumberPlate(String numberPlate) {
        this.numberPlate = numberPlate;
    }
    public Date getReceivedDate() {
        return receivedDate;
    }

    public void setReceivedDate(Date receivedDate) {
        this.receivedDate = receivedDate;
    }
    public BigDecimal getTotal() {
        return total;
    }

    public void setTotal(BigDecimal total) {
        this.total = total;
    }
    public Long getPurchasereceiptId() {
        return purchasereceiptId;
    }

    public void setPurchasereceiptId(Long purchasereceiptId) {
        this.purchasereceiptId = purchasereceiptId;
    }
    public Long getMaterialId() {
        return materialId;
    }

    public void setMaterialId(Long materialId) {
        this.materialId = materialId;
    }
    public String getMaterialName() {
        return materialName;
    }

    public void setMaterialName(String materialName) {
        this.materialName = materialName;
    }
    
}
